"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UsernameChecker = void 0;
const axios_1 = __importStar(require("axios"));
const config_1 = require("./config");
const https_1 = __importDefault(require("https"));
class UsernameChecker {
    isAvailable(service, username) {
        var _a, _b;
        return __awaiter(this, void 0, void 0, function* () {
            const serviceDetail = this.getServiceDetail(service);
            const result = {
                service,
                url: serviceDetail.url.replace('{{ username }}', username),
                available: false,
            };
            let response;
            try {
                const httpsAgent = new https_1.default.Agent({
                    rejectUnauthorized: false,
                });
                response = yield axios_1.default.get(result.url, {
                    httpsAgent,
                    timeout: 5000,
                    headers: {
                        'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/111.0.0.0 Safari/537.36',
                    },
                });
            }
            catch (error) {
                if (error instanceof axios_1.AxiosError) {
                    if (error.code === 'ECONNABORTED') {
                        result.available = undefined;
                        result.reason = `Unable to connect to ${service}`;
                        return result;
                    }
                    else if ((_a = error.response) === null || _a === void 0 ? void 0 : _a.status) {
                        if (error.response.status >= 500) {
                            result.available = undefined;
                            result.reason = `${service} faced internal server error.`;
                            return result;
                        }
                        else if (error.response.status >= 400 && ![404, 410].includes(error.response.status)) {
                            result.available = undefined;
                            result.reason = `Unknown error occured with ${service}`;
                            return result;
                        }
                    }
                }
                response = error.response;
            }
            for (const rule of serviceDetail.rules) {
                switch (rule.name) {
                    case config_1.UsernameCheckerRuleNameEnum.STATUS_404:
                        if ([404, 410].includes(response.status)) {
                            result.available = true;
                        }
                        break;
                    case config_1.UsernameCheckerRuleNameEnum.AVAILABLE:
                        if (rule.matches) {
                            let data = response.data;
                            if ((_b = response.headers['content-type']) === null || _b === void 0 ? void 0 : _b.toString().includes('application/json')) {
                                data = JSON.stringify(data);
                            }
                            for (const match of rule.matches) {
                                const test = new RegExp(match, 'gi').test(data);
                                if (test) {
                                    result.available = true;
                                    break;
                                }
                            }
                        }
                        break;
                }
                if (result.available) {
                    break;
                }
            }
            return result;
        });
    }
    getServiceDetail(service) {
        return config_1.UsernameCheckerServices[service];
    }
    getServices() {
        return Object.keys(config_1.UsernameCheckerServices);
    }
}
exports.UsernameChecker = UsernameChecker;
